@@ -163,14 +163,12 @@ func runBrowse(opts *BrowseOptions) error {
 		return fmt.Errorf("unable to determine base repository: %w", err)
 	}
 
-	if opts.Commit != "" {
-		if opts.Commit == emptyCommitFlag {
-			commit, err := opts.GitClient.LastCommit()
-			if err != nil {
-				return err
-			}
-			opts.Commit = commit.Sha
+	if opts.Commit != "" && opts.Commit == emptyCommitFlag {
+		commit, err := opts.GitClient.LastCommit()
+		if err != nil {
+			return err
 		}
+		opts.Commit = commit.Sha
 	}
 
 	section, err := parseSection(baseRepo, opts)
