@@ -12,21 +12,23 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/config"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/pkg/cmd/gist/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/cli/cli/v2/pkg/surveyext"
 	"github.com/spf13/cobra"
 )
 
+var editNextOptions = []string{"Edit another file", "Submit", "Cancel"}
+
 type EditOptions struct {
 	IO         *iostreams.IOStreams
 	HttpClient func() (*http.Client, error)
 	Config     func() (config.Config, error)
+	Prompter   prompter.Prompter
 
 	Edit func(string, string, string, *iostreams.IOStreams) (string, error)
 
@@ -42,6 +44,7 @@ func NewCmdEdit(f *cmdutil.Factory, runF func(*EditOptions) error) *cobra.Comman
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
 		Config:     f.Config,
+		Prompter:   f.Prompter,
 		Edit: func(editorCmd, filename, defaultContent string, io *iostreams.IOStreams) (string, error) {
 			return surveyext.Edit(
 				editorCmd,
@@ -55,16 +58,15 @@ func NewCmdEdit(f *cmdutil.Factory, runF func(*EditOptions) error) *cobra.Comman
 		Use:   "edit {<id> | <url>} [<filename>]",
 		Short: "Edit one of your gists",
 		Args: func(cmd *cobra.Command, args []string) error {
-			if len(args) < 1 {
-				return cmdutil.FlagErrorf("cannot edit: gist argument required")
-			}
 			if len(args) > 2 {
 				return cmdutil.FlagErrorf("too many arguments")
 			}
 			return nil
 		},
 		RunE: func(c *cobra.Command, args []string) error {
-			opts.Selector = args[0]
+			if len(args) > 0 {
+				opts.Selector = args[0]
+			}
 			if len(args) > 1 {
 				opts.SourceFile = args[1]
 			}
@@ -85,7 +87,33 @@ func NewCmdEdit(f *cmdutil.Factory, runF func(*EditOptions) error) *cobra.Comman
 }
 
 func editRun(opts *EditOptions) error {
+	client, err := opts.HttpClient()
+	if err != nil {
+		return err
+	}
+
+	cfg, err := opts.Config()
+	if err != nil {
+		return err
+	}
+
+	host, _ := cfg.Authentication().DefaultHost()
+
 	gistID := opts.Selector
+	if gistID == "" {
+		cs := opts.IO.ColorScheme()
+		if gistID == "" {
+			gistID, err = shared.PromptGists(opts.Prompter, client, host, cs)
+			if err != nil {
+				return err
+			}
+
+			if gistID == "" {
+				fmt.Fprintln(opts.IO.Out, "No gists found.")
+				return nil
+			}
+		}
+	}
 
 	if strings.Contains(gistID, "/") {
 		id, err := shared.GistIDFromURL(gistID)
@@ -95,23 +123,8 @@ func editRun(opts *EditOptions) error {
 		gistID = id
 	}
 
-	client, err := opts.HttpClient()
-	if err != nil {
-		return err
-	}
-
 	apiClient := api.NewClientFromHTTP(client)
 
-	cfg, err := opts.Config()
-	if err != nil {
-		return err
-	}
-
-	host, err := cfg.DefaultHost()
-	if err != nil {
-		return err
-	}
-
 	gist, err := shared.GetGist(client, host, gistID)
 	if err != nil {
 		if errors.Is(err, shared.NotFoundErr) {
@@ -192,14 +205,11 @@ func editRun(opts *EditOptions) error {
 				if !opts.IO.CanPrompt() {
 					return errors.New("unsure what file to edit; either specify --filename or run interactively")
 				}
-				err = prompt.SurveyAskOne(&survey.Select{
-					Message: "Edit which file?",
-					Options: candidates,
-				}, &filename)
-
+				result, err := opts.Prompter.Select("Edit which file?", "", candidates)
 				if err != nil {
 					return fmt.Errorf("could not prompt: %w", err)
 				}
+				filename = candidates[result]
 			}
 		}
 
@@ -251,19 +261,11 @@ func editRun(opts *EditOptions) error {
 		}
 
 		choice := ""
-
-		err = prompt.SurveyAskOne(&survey.Select{
-			Message: "What next?",
-			Options: []string{
-				"Edit another file",
-				"Submit",
-				"Cancel",
-			},
-		}, &choice)
-
+		result, err := opts.Prompter.Select("What next?", "", editNextOptions)
 		if err != nil {
 			return fmt.Errorf("could not prompt: %w", err)
 		}
+		choice = editNextOptions[result]
 
 		stop := false
 
