@@ -3,17 +3,18 @@ package edit
 import (
 	"bytes"
 	"encoding/json"
-	"io/ioutil"
+	"io"
 	"net/http"
+	"os"
 	"path/filepath"
 	"testing"
 
 	"github.com/cli/cli/v2/internal/config"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/pkg/cmd/gist/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/httpmock"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -110,19 +111,19 @@ func TestNewCmdEdit(t *testing.T) {
 
 func Test_editRun(t *testing.T) {
 	fileToAdd := filepath.Join(t.TempDir(), "gist-test.txt")
-	err := ioutil.WriteFile(fileToAdd, []byte("hello"), 0600)
+	err := os.WriteFile(fileToAdd, []byte("hello"), 0600)
 	require.NoError(t, err)
 
 	tests := []struct {
-		name       string
-		opts       *EditOptions
-		gist       *shared.Gist
-		httpStubs  func(*httpmock.Registry)
-		askStubs   func(*prompt.AskStubber)
-		nontty     bool
-		stdin      string
-		wantErr    string
-		wantParams map[string]interface{}
+		name          string
+		opts          *EditOptions
+		gist          *shared.Gist
+		httpStubs     func(*httpmock.Registry)
+		prompterStubs func(*prompter.MockPrompter)
+		nontty        bool
+		stdin         string
+		wantErr       string
+		wantParams    map[string]interface{}
 	}{
 		{
 			name:    "no such gist",
@@ -160,9 +161,17 @@ func Test_editRun(t *testing.T) {
 		},
 		{
 			name: "multiple files, submit",
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Edit which file?").AnswerWith("unix.md")
-				as.StubPrompt("What next?").AnswerWith("Submit")
+			prompterStubs: func(pm *prompter.MockPrompter) {
+				pm.RegisterSelect("Edit which file?",
+					[]string{"cicada.txt", "unix.md"},
+					func(_, _ string, opts []string) (int, error) {
+						return prompter.IndexFor(opts, "unix.md")
+					})
+				pm.RegisterSelect("What next?",
+					editNextOptions,
+					func(_, _ string, opts []string) (int, error) {
+						return prompter.IndexFor(opts, "Submit")
+					})
 			},
 			gist: &shared.Gist{
 				ID:          "1234",
@@ -205,9 +214,17 @@ func Test_editRun(t *testing.T) {
 		},
 		{
 			name: "multiple files, cancel",
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Edit which file?").AnswerWith("unix.md")
-				as.StubPrompt("What next?").AnswerWith("Cancel")
+			prompterStubs: func(pm *prompter.MockPrompter) {
+				pm.RegisterSelect("Edit which file?",
+					[]string{"cicada.txt", "unix.md"},
+					func(_, _ string, opts []string) (int, error) {
+						return prompter.IndexFor(opts, "unix.md")
+					})
+				pm.RegisterSelect("What next?",
+					editNextOptions,
+					func(_, _ string, opts []string) (int, error) {
+						return prompter.IndexFor(opts, "Cancel")
+					})
 			},
 			wantErr: "CancelError",
 			gist: &shared.Gist{
@@ -473,11 +490,11 @@ func Test_editRun(t *testing.T) {
 		tt.opts.HttpClient = func() (*http.Client, error) {
 			return &http.Client{Transport: reg}, nil
 		}
-		io, stdin, stdout, stderr := iostreams.Test()
+		ios, stdin, stdout, stderr := iostreams.Test()
 		stdin.WriteString(tt.stdin)
-		io.SetStdoutTTY(!tt.nontty)
-		io.SetStdinTTY(!tt.nontty)
-		tt.opts.IO = io
+		ios.SetStdoutTTY(!tt.nontty)
+		ios.SetStdinTTY(!tt.nontty)
+		tt.opts.IO = ios
 		tt.opts.Selector = "1234"
 
 		tt.opts.Config = func() (config.Config, error) {
@@ -485,10 +502,11 @@ func Test_editRun(t *testing.T) {
 		}
 
 		t.Run(tt.name, func(t *testing.T) {
-			as := prompt.NewAskStubber(t)
-			if tt.askStubs != nil {
-				tt.askStubs(as)
+			pm := prompter.NewMockPrompter(t)
+			if tt.prompterStubs != nil {
+				tt.prompterStubs(pm)
 			}
+			tt.opts.Prompter = pm
 
 			err := editRun(tt.opts)
 			reg.Verify(t)
@@ -499,7 +517,7 @@ func Test_editRun(t *testing.T) {
 			assert.NoError(t, err)
 
 			if tt.wantParams != nil {
-				bodyBytes, _ := ioutil.ReadAll(reg.Requests[2].Body)
+				bodyBytes, _ := io.ReadAll(reg.Requests[2].Body)
 				reqBody := make(map[string]interface{})
 				err = json.Unmarshal(bodyBytes, &reqBody)
 				if err != nil {
