@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"net/http"
 	"net/url"
+	"os"
 	"regexp"
 	"strings"
 	"time"
@@ -60,6 +61,7 @@ type CreateOptions struct {
 	Milestone string
 
 	MaintainerCanModify bool
+	Template            string
 }
 
 type CreateContext struct {
@@ -128,6 +130,12 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 
 			opts.TitleProvided = cmd.Flags().Changed("title")
 			opts.RepoOverride, _ = cmd.Flags().GetString("repo")
+			// Workaround: Due to the way this command is implemented, we need to manually check GH_REPO.
+			// Commands should use the standard BaseRepoOverride functionality to handle this behavior instead.
+			if opts.RepoOverride == "" {
+				opts.RepoOverride = os.Getenv("GH_REPO")
+			}
+
 			noMaintainerEdit, _ := cmd.Flags().GetBool("no-maintainer-edit")
 			opts.MaintainerCanModify = !noMaintainerEdit
 
@@ -155,6 +163,10 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 				opts.BodyProvided = true
 			}
 
+			if opts.Template != "" && opts.BodyProvided {
+				return errors.New("`--template` is not supported when using `--body` or `--body-file`")
+			}
+
 			if !opts.IO.CanPrompt() && !opts.WebMode && !opts.Autofill && (!opts.TitleProvided || !opts.BodyProvided) {
 				return cmdutil.FlagErrorf("must provide `--title` and `--body` (or `--fill`) when not running interactively")
 			}
@@ -182,6 +194,9 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 	fl.StringVarP(&opts.Milestone, "milestone", "m", "", "Add the pull request to a milestone by `name`")
 	fl.Bool("no-maintainer-edit", false, "Disable maintainer's ability to modify pull request")
 	fl.StringVar(&opts.RecoverFile, "recover", "", "Recover input from a failed run of create")
+	fl.StringVarP(&opts.Template, "template", "T", "", "Template `file` to use as starting body text")
+
+	_ = cmdutil.RegisterBranchCompletionFlags(f.GitClient, cmd, "base", "head")
 
 	_ = cmd.RegisterFlagCompletionFunc("reviewer", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		results, err := requestableReviewersForCompletion(opts)
@@ -295,15 +310,21 @@ func createRun(opts *CreateOptions) (err error) {
 		if opts.RecoverFile == "" {
 			tpl := shared.NewTemplateManager(client.HTTP(), ctx.BaseRepo, opts.Prompter, opts.RootDirOverride, opts.RepoOverride == "", true)
 			var template shared.Template
-			template, err = tpl.Choose()
-			if err != nil {
-				return
+
+			if opts.Template != "" {
+				template, err = tpl.Select(opts.Template)
+				if err != nil {
+					return
+				}
+			} else {
+				template, err = tpl.Choose()
+				if err != nil {
+					return
+				}
 			}
 
 			if template != nil {
 				templateContent = string(template.Body())
-			} else {
-				templateContent = string(tpl.LegacyBody())
 			}
 		}
 
