@@ -1,16 +1,20 @@
 package create
 
 import (
+	"bytes"
 	"context"
 	"errors"
 	"fmt"
+	"io"
 	"net/http"
 	"os/exec"
 	"path/filepath"
 	"sort"
 	"strings"
+	"time"
 
 	"github.com/MakeNowJust/heredoc"
+	"github.com/cenkalti/backoff/v4"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/config"
@@ -21,6 +25,10 @@ import (
 	"github.com/spf13/cobra"
 )
 
+type errWithExitCode interface {
+	ExitCode() int
+}
+
 type iprompter interface {
 	Input(string, string) (string, error)
 	Select(string, string, []string) (int, error)
@@ -33,6 +41,7 @@ type CreateOptions struct {
 	Config     func() (config.Config, error)
 	IO         *iostreams.IOStreams
 	Prompter   iprompter
+	BackOff    backoff.BackOff
 
 	Name               string
 	Description        string
@@ -387,17 +396,12 @@ func createFromScratch(opts *CreateOptions) error {
 
 		remoteURL := ghrepo.FormatRemoteURL(repo, protocol)
 
-		if opts.LicenseTemplate == "" && opts.GitIgnoreTemplate == "" {
+		if opts.LicenseTemplate == "" && opts.GitIgnoreTemplate == "" && opts.Template == "" {
 			// cloning empty repository or template
-			checkoutBranch := ""
-			if opts.Template != "" {
-				// use the template's default branch
-				checkoutBranch = templateRepoMainBranch
-			}
-			if err := localInit(opts.GitClient, remoteURL, repo.RepoName(), checkoutBranch); err != nil {
+			if err := localInit(opts.GitClient, remoteURL, repo.RepoName()); err != nil {
 				return err
 			}
-		} else if _, err := opts.GitClient.Clone(context.Background(), remoteURL, []string{}); err != nil {
+		} else if err := cloneWithRetry(opts, remoteURL, templateRepoMainBranch); err != nil {
 			return err
 		}
 	}
@@ -563,6 +567,33 @@ func createFromLocal(opts *CreateOptions) error {
 	return nil
 }
 
+func cloneWithRetry(opts *CreateOptions, remoteURL, branch string) error {
+	// Allow injecting alternative BackOff in tests.
+	if opts.BackOff == nil {
+		opts.BackOff = backoff.NewConstantBackOff(3 * time.Second)
+	}
+
+	var args []string
+	if branch != "" {
+		args = append(args, "--branch", branch)
+	}
+
+	ctx := context.Background()
+	return backoff.Retry(func() error {
+		stderr := &bytes.Buffer{}
+		_, err := opts.GitClient.Clone(ctx, remoteURL, args, git.WithStderr(stderr))
+
+		var execError errWithExitCode
+		if errors.As(err, &execError) && execError.ExitCode() == 128 {
+			return err
+		} else {
+			_, _ = io.Copy(opts.IO.ErrOut, stderr)
+		}
+
+		return backoff.Permanent(err)
+	}, backoff.WithContext(backoff.WithMaxRetries(opts.BackOff, 3), ctx))
+}
+
 func sourceInit(gitClient *git.Client, io *iostreams.IOStreams, remoteURL, baseRemote string) error {
 	cs := io.ColorScheme()
 	remoteAdd, err := gitClient.Command(context.Background(), "remote", "add", baseRemote, remoteURL)
@@ -620,7 +651,7 @@ func isLocalRepo(gitClient *git.Client) (bool, error) {
 }
 
 // clone the checkout branch to specified path
-func localInit(gitClient *git.Client, remoteURL, path, checkoutBranch string) error {
+func localInit(gitClient *git.Client, remoteURL, path string) error {
 	ctx := context.Background()
 	gitInit, err := gitClient.Command(ctx, "init", path)
 	if err != nil {
@@ -631,8 +662,8 @@ func localInit(gitClient *git.Client, remoteURL, path, checkoutBranch string) er
 		return err
 	}
 
-	// Clone the client so we do not modify the original client's RepoDir.
-	gc := cloneGitClient(gitClient)
+	// Copy the client so we do not modify the original client's RepoDir.
+	gc := gitClient.Copy()
 	gc.RepoDir = path
 
 	gitRemoteAdd, err := gc.Command(ctx, "remote", "add", "origin", remoteURL)
@@ -644,17 +675,7 @@ func localInit(gitClient *git.Client, remoteURL, path, checkoutBranch string) er
 		return err
 	}
 
-	if checkoutBranch == "" {
-		return nil
-	}
-
-	refspec := fmt.Sprintf("+refs/heads/%[1]s:refs/remotes/origin/%[1]s", checkoutBranch)
-	err = gc.Fetch(ctx, "origin", refspec)
-	if err != nil {
-		return err
-	}
-
-	return gc.CheckoutBranch(ctx, checkoutBranch)
+	return nil
 }
 
 func interactiveGitIgnore(client *http.Client, hostname string, prompter iprompter) (string, error) {
@@ -709,7 +730,7 @@ func interactiveRepoInfo(client *http.Client, hostname string, prompter iprompte
 		name = fmt.Sprintf("%s/%s", owner, name)
 	}
 
-	description, err := prompter.Input("Description", defaultName)
+	description, err := prompter.Input("Description", "")
 	if err != nil {
 		return "", "", "", err
 	}
@@ -773,14 +794,3 @@ func splitNameAndOwner(name string) (string, string, error) {
 	}
 	return repo.RepoName(), repo.RepoOwner(), nil
 }
-
-func cloneGitClient(c *git.Client) *git.Client {
-	return &git.Client{
-		GhPath:  c.GhPath,
-		RepoDir: c.RepoDir,
-		GitPath: c.GitPath,
-		Stderr:  c.Stderr,
-		Stdin:   c.Stdin,
-		Stdout:  c.Stdout,
-	}
-}
