@@ -20,6 +20,7 @@ type Extension interface {
 	Path() string // Path to executable
 	URL() string
 	CurrentVersion() string
+	LatestVersion() string
 	IsPinned() bool
 	UpdateAvailable() bool
 	IsBinary() bool
@@ -28,11 +29,12 @@ type Extension interface {
 
 //go:generate moq -rm -out manager_mock.go . ExtensionManager
 type ExtensionManager interface {
-	List(includeMetadata bool) []Extension
+	List() []Extension
 	Install(ghrepo.Interface, string) error
 	InstallLocal(dir string) error
 	Upgrade(name string, force bool) error
 	Remove(name string) error
 	Dispatch(args []string, stdin io.Reader, stdout, stderr io.Writer) (bool, error)
 	Create(name string, tmplType ExtTemplateType) error
+	EnableDryRunMode()
 }
